@@ -233,11 +233,16 @@ fn generate_<'a>(cert: &ValidCert<'a>, fqdn: &str, ttl: Option<Duration>,
             for uidb in vcert.userids() {
                 acc.push(uidb.userid().clone().into());
                 match uidb.revocation_status() {
-                    | RevocationStatus::Revoked(revs)
-                    | RevocationStatus::CouldBe(revs) => {
+                    RevocationStatus::Revoked(revs) => {
                         revs.iter()
                             .for_each(|&s| acc.push(s.clone().into()));
                     },
+                    RevocationStatus::CouldBe(revs) => {
+                        revs.iter()
+                            .for_each(|&s| acc.push(s.clone().into()));
+                        uidb.signatures()
+                            .for_each(|s| acc.push(s.clone().into()));
+                    },
                     RevocationStatus::NotAsFarAsWeKnow => {
                         uidb.signatures()
                             .for_each(|s| acc.push(s.clone().into()));
@@ -248,11 +253,16 @@ fn generate_<'a>(cert: &ValidCert<'a>, fqdn: &str, ttl: Option<Duration>,
             for skb in vcert.keys().subkeys() {
                 acc.push(skb.key().clone().into());
                 match skb.revocation_status() {
-                    | RevocationStatus::Revoked(revs)
-                    | RevocationStatus::CouldBe(revs) => {
+                    RevocationStatus::Revoked(revs) => {
                         revs.iter()
                             .for_each(|&s| acc.push(s.clone().into()));
                     },
+                    RevocationStatus::CouldBe(revs) => {
+                        revs.iter()
+                            .for_each(|&s| acc.push(s.clone().into()));
+                        skb.signatures()
+                            .for_each(|s| acc.push(s.clone().into()));
+                    },
                     RevocationStatus::NotAsFarAsWeKnow => {
                         skb.signatures()
                             .for_each(|s| acc.push(s.clone().into()));
